package com.cxzx;

import com.cxzx.config.KafkaConfig;
import com.cxzx.db.KafkaData;
import com.cxzx.db.Tidb;
import lombok.extern.slf4j.Slf4j;
import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.apache.kafka.clients.consumer.KafkaConsumer;
import org.apache.kafka.clients.consumer.OffsetAndMetadata;
import org.apache.kafka.common.TopicPartition;

import java.sql.Timestamp;
import java.time.Duration;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

@Slf4j
public class Main {
    public static void main(String[] args) {

        var consumer = new KafkaConsumer<String, String>(KafkaConfig.getKafkaProperties());

        try (consumer) {
            consumer.subscribe(List.of("article"));
            while (true) {
                var kafkaDataList = new ArrayList<KafkaData>();
                for (ConsumerRecord<String, String> record : consumer.poll(Duration.ofMillis(2000))) {
                    kafkaDataList.add(new KafkaData(record.offset(), record.value(), new Timestamp(record.timestamp())));
                    var offsetMap = Map.of(new TopicPartition(record.topic(), record.partition()), new OffsetAndMetadata(record.offset()));
                    consumer.commitSync(offsetMap);
                }
                Tidb.insert(kafkaDataList);
            }
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }

    }

}
